/**************************************************************************
** 
** File name   : bstrap_biascorrection_chap6.do
** Date        : July 18, 2008
** Author      : Christina J. Schneider 
** Purpose     : Replicates Table 6.1, 6.2 (Bootstrapped and Bias-Corrected 
			Confidence Intervals and Model Fit)  
** Requires    : dyads.dta
** Output      : bstrap_biascorrection_chap6
** Info	   : README
**
**************************************************************************/

version 10.0
#delimit ;

drop _all;
program drop _all;

set more off;

qui log;
loc logopen = r(status);
if "`logopen'" == "on" {; log close; };

set logtype text;
log using bstrap_biascorrection_chap6.log, replace;
di "$S_DATE $S_TIME";

loc confidence_level = 95;

program define _bias_correction;
    syntax varname, BHAT(real) CONFidence(integer);

    scalar alpha = (1-`confidence'/100)/2;

    qui summ `varlist';
    scalar N = r(N);
    qui count if `varlist' < `bhat';
    scalar frac_less = r(N) / N;

    scalar z0 = invnormal(frac_less);  /* median bias */
    scalar z_alpha2 = invnormal(1-alpha);
    scalar p1 = normal(2*z0 - z_alpha2);
    scalar p2 = normal(2*z0 + z_alpha2);

    loc pct1 = 100*p1;
    loc pct2 = 100*p2;

    _pctile `varlist', p(`pct1' `pct2');
    di "`varlist'";
    di "    estimate: " `bhat';
    di "    `confidence'% CI: (" r(r1) "," r(r2) ")";
end;

program define bstrap_correct;
    syntax varlist, DEMAND(varname) DISCR(varname) AREA(name) CONFidence(integer);
    loc discrimination_model "ceiling importfromeu share_exp perccouncil_change";

    preserve;

    /* get the coefficients */
    quietly {;
        probit `demand' `varlist', cluster(oldmembers);
        predict prob_demand, pr;
        probit `discr' prob_demand `discrimination_model', cluster(oldmembers);
    };
    loc bhat_prob_demand = _b[prob_demand];
    loc bhat_ceiling = _b[ceiling];
    loc bhat_importfromeu = _b[importfromeu];
    loc bhat_share_exp = _b[share_exp];
    loc bhat_perccouncil_change = _b[perccouncil_change];
    loc bhat_cons = _b[_cons];

    /* get percent correct, etc */
    quietly {;
        predict prob_discr, pr;
        gen pred_discr = (prob_discr > .5);
    };
    tabulate `discr' pred_discr, matcell(freqs);
    /* what perecent of predictions was correct */
    loc pctok = (freqs[1,1] + freqs[2,2]) / r(N);
    /* of predicted no's, how many were correct */
    loc pctnok = freqs[1,1] / (freqs[1,1] + freqs[2,1]);
    /* of predicted yes's, how many were correct */
    loc pctyok = freqs[2,2] / (freqs[2,2] + freqs[1,2]);

    /* get bootstrapped results */
    qui drop _all;
    qui use bstrap_`area', clear;

    _bias_correction _b_prob_`area', bhat(`bhat_prob_demand') conf(`confidence');
    _bias_correction _b_ceiling, bhat(`bhat_ceiling') conf(`confidence');
    _bias_correction _b_importfromeu, bhat(`bhat_importfromeu') conf(`confidence');
    _bias_correction _b_share_exp, bhat(`bhat_share_exp') conf(`confidence');
    _bias_correction _b_perccouncil_change, bhat(`bhat_perccouncil_change') conf(`confidence');
    _bias_correction _b_cons, bhat(`bhat_cons') conf(`confidence');

    loc lb = (100-`confidence')/2;
    loc ub = 100 - `lb';
    quietly {;
        sum _eq2_pctok;
        loc mean = r(mean);
        _pctile _eq2_pctok, p(`lb' `ub');
    };
    di "pctok";
    di "    estimate: " `mean';
    di "    `confidence'% CI: (" r(r1) "," r(r2) ")";

    quietly {;
        sum _eq2_pctyok;
        loc mean = r(mean);
        _pctile _eq2_pctyok, p(`lb' `ub');
    };
    di "pctyok";
    di "    estimate: " `mean';
    di "    `confidence'% CI: (" r(r1) "," r(r2) ")";

    quietly {;
        sum _eq2_pctnok;
        loc mean = r(mean);
        _pctile _eq2_pctnok, p(`lb' `ub');
    };
    di "pctnok";
    di "    estimate: " `mean';
    di "    `confidence'% CI: (" r(r1) "," r(r2) ")";

    restore;
end;

loc demand_fmw = "bipn_eu100 distance foreign erwerbindo erwerbindn unempln unemplo";
loc demand_csp = "bipn_eu100 fundo sizen erwerbindn erwerblandn contribution";
loc demand_cap = "totagrn totagro sizen contribution";

use dyads, clear;
bstrap_correct `demand_fmw', demand(demand_fmw) discr(discr_fmw) area(fmw) conf(`confidence_level');
bstrap_correct `demand_cap', demand(demand_cap) discr(discr_cap) area(cap) conf(`confidence_level');
bstrap_correct `demand_csp', demand(demand_csp) discr(discr_csp) area(csp) conf(`confidence_level');

log close;
set more on;