/**************************************************************************
** 
** File name   : bstrap_sims_chap6.do
** Date        : July 18, 2008
** Author      : Christina J. Schneider 
** Purpose     : Replicates Predicted Probabilities (Table 6.3 and Figures) 
** Requires    : dyads.dta, estsimpx.ado, simqix.ado
** Output      : bstrap_sims_chap6.log
** Info        : README
**
**************************************************************************/


version 10.0
#delimit ;



drop _all;
program drop _all;
program drop _allado;

/*
** this gets the unbiased point estimates from one run of the 
** model and then loads the variance/covariance
** matrix from the data file saved by the bootstrap run
** for purposes of clarify, this program mimics probit
**
** NOTE
**     this re-generates prob_`area' predicted probabilities of demand
**     from the first stage of the model
*/
program define bcse_probit, eclass;
    version 10.0;
    syntax varlist [if], AREA(name) [Level(cilevel)];

    loc demand_model_fmw = "bipn_eu100 distance foreign erwerbindo erwerbindn unempln unemplo";
    loc demand_model_csp = "bipn_eu100 fundo sizen erwerbindn erwerblandn contribution";
    loc demand_model_cap = "totagrn totagro sizen contribution";

    /* extract the dependent variable from varlist and drop it */
    loc discr = word("`varlist'",1);
    loc varlist = subinword("`varlist'","`discr'","",1);

    loc demand = "demand_fmw";
    loc demand_model = "`demand_model_fmw'";

    if "`area'" == "cap" {;    
        loc demand = "demand_cap";
        loc demand_model = "`demand_model_cap'";
    };
    else if "`area'" == "csp" {;
        loc demand = "demand_csp";
        loc demand_model = "`demand_model_csp'";
    };

    /* we have some extra stuff in the file (the okpct vars) that we don't want 
    ** prefix the varnames with _b_'varname' and then ask bstat for these only
    */
    loc bsvarlist = "`varlist'";
    loc nvars: word count `bsvarlist';
    loc bsnames "";
    loc i = 1;
    while `i' <= `nvars' {;
        loc w: word `i' of `bsvarlist';
        loc bsnames = "`bsnames' _b_`w'";
        loc i = `i' + 1;
    };
    loc bsnames = "`bsnames' _b_cons";

    /* this puts observed stats in b and bootstrap var/covar matrix in V */
    bstat `bsnames' using bstrap_`area';
    mat bsV = e(V);
    /* 
    ** run probits and replace the variance/covariance matrix with one from bootstrap
    */
    quietly {;
        drop prob_`area';
        probit `demand' `demand_model', cluster(oldmembers);
        predict prob_`area', pr;
    };
    probit `discr' `varlist', cluster(oldmembers);
    mat b = e(b);
    mat pV = e(V);
    * mat list pV;
    * mat list bsV;
    * mat pV[1,1] = bsV;

    sca N_clust = e(N_clust);
    sca N = e(N);
    sca ll_0 = e(ll_0);
    sca ll = e(ll);
    sca df_m = e(df_m);
    sca chi2 = e(chi2);
    sca r2_p = e(r2_p);
    sca N_cdf = e(N_cdf);
    sca N_cds = e(N_cds);

    loc cmdline = e(cmdline);
    loc title = e(title);
    loc vce = e(vce);
    loc depvar = e(depvar);
    loc cmd = e(cmd);
    loc crittype = e(crittype);
    loc predict = e(predict);
    loc properties = e(properties);
    loc estat_cmd = e(estat_cmd);
    loc chi2type = e(chi2type);
    loc vcetype = e(vcetype);
    loc clustvar = e(clustvar);

    ereturn post b pV;

    ereturn sca N_clust = N_clust;
    ereturn sca N = N;
    ereturn sca ll_0 = ll_0;
    ereturn sca ll = ll;
    ereturn sca df_m = df_m;
    ereturn sca chi2 = chi2;
    ereturn sca r2_p = r2_p;
    ereturn sca N_cdf = N_cdf;
    ereturn sca N_cds = N_cds;

    ereturn loc cmdline `cmdline';
    ereturn loc title `title';
    ereturn loc vce `vce';
    ereturn loc depvar `depvar';
    ereturn loc cmd `cmd';
    ereturn loc crittype `crittype';
    ereturn loc predict `predict';
    ereturn loc properties `properties';
    ereturn loc estat_cmd `estat_cmd';
    ereturn loc chi2type `chi2type';
    ereturn loc vcetype `vcetype';
    ereturn loc clustvar `clustvar';

    glo S_E_cmd = "`cmd'";
    glo S_E_depv = "`depvar'";
    glo S_E_vce = "`vcetype'";
end;

/*
** Call simexpci varname, ticks(obs_to_generate) conf(conf_level)
**      ticks(n) is how many observation b/n auth min and max to generate
**      conf(n)  is the confidence level for the intervals (default 95%)
** RETURNS
**      sim_x with `ticks' observations from min to max of `varname'
**      sim_exp  expected value of dependent var
**      sim_ciL and sim_ciH: the lower and upper bounds of conf. interval
** NOTE
**      uses patched Clarify command simqi (as simqix)
*/
program define simexpci;
    syntax varname, TICKS(integer) [CONF(integer $S_level)];

    tempvar dummyvar expvar;

    * calc bounds for conf. intervals;
    loc left = (100-`conf')/2;
    loc right = 100-`left';

    * at least two ticks for end values;
    loc ticks = cond(`ticks'>1,`ticks',2);

    * calc values for `varname' from ticks;
    qui sum `varlist';
    loc themin = r(min);
    loc themax = r(max);
    loc thestep = (`themax'-`themin')/(`ticks'-1);

    * generate place-holder variables;
    capture confirm new var sim_x;
    if _rc == 0 {;
        loc next = `themin'+`thestep';
        qui egen sim_x = fill(`themin' `next');
        qui replace sim_x = . if sim_x > `themax';

        qui gen sim_exp = .;
        label var sim_exp "Expected value";
        qui gen sim_ciL = .;
        label var sim_ciL "Lower bound (ci)";
        qui gen sim_ciH = .;
        label var sim_ciH "Upper bound (ci)";
    };

    * predict and stuff into variables;
    loc i = 1;
    loc prevpct = 0;
    di _n "% complete: " _c;
    while `i' <= `ticks' {;
        loc percent = int(`i'*100/`ticks');
        if `percent'>=`prevpct'+20 {;
            loc prevpct = `percent';
            di "`percent'.." _c;
        };

        loc x = min(`themin' + `thestep'*(`i'-1), `themax');
        qui replace sim_x = `x' if _n==`i';
        setx `varlist' `x';

        qui simqix, genpr(`dummyvar' `expvar');
        /* we want pr(y=1) only, so take 2nd argument */
        su `expvar', meanonly;
        qui replace sim_exp = r(mean) if _n==`i';
        _pctile `expvar', p(`left' `right');
        qui replace sim_ciL = r(r1) if _n==`i';
        qui replace sim_ciH = r(r2) if _n==`i';

        drop `dummyvar' `expvar';
        loc i = `i' + 1;
    };
    di "Done";
end;

/*
****************************************************************************
** MAIN PROGRAM
****************************************************************************
*/
drop _all;
set more off;
set logtype text;
set linesize 90;

log query;
loc logstatus = r(status);
if "`logstatus'" == "on" {; 
	log close; 
};
log using bstrap_sims_chap6, replace;

di "Graphs for the Models in Chapter 6";
di "$S_DATE $S_TIME";

use dyads, clear;

/* idiotic hack b/c clarify wants varlist and prob_??? not in current dataset */
qui gen prob_fmw = .;
qui gen prob_cap = .;
qui gen prob_csp = .;

loc discrimination_model "ceiling importfromeu share_exp perccouncil_change";

/***************************************************************************
** Free Movement of Workers
*/
set seed 160773;
estsimpx bcse_probit discr_fmw prob_fmw `discrimination_model', area(fmw);

setx prob_fmw p25 (ceiling perccouncil_change) p25 (importfromeu share_exp) p75;
simqix, prval(1) listx;
setx prob_fmw median (ceiling perccouncil_change) p25 (importfromeu share_exp) p75;
simqix, prval(1) listx;
setx prob_fmw p75 (ceiling perccouncil_change) p25 (importfromeu share_exp) p75;
simqix, prval(1) listx;

setx median;
setx prob_fmw p25;
simqix, prval(1) listx;
setx prob_fmw median;
simqix, prval(1) listx;
setx prob_fmw p75;
simqix, prval(1) listx;

setx prob_fmw p25 (ceiling perccouncil_change) p75 (importfromeu share_exp) p25;
simqix, prval(1) listx;
setx prob_fmw median (ceiling perccouncil_change) p75 (importfromeu share_exp) p25;
simqix, prval(1) listx;
setx prob_fmw p75 (ceiling perccouncil_change) p75 (importfromeu share_exp) p25;
simqix, prval(1) listx;

setx median;
simexpci perccouncil_change, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("EU Member Council Power") 
    ytitle("Probability of Discrimination") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppdcvoting_fmw.eps, replace;
qui drop sim_*;

setx (ceiling perccouncil_change) p25 (importfromeu share_exp) p75;
simexpci prob_fmw, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("Probability of Discrimination Demand") 
    ytitle("Probability of Discrimination") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppd_fmw.eps, replace;
qui drop sim_*;

setx median;
simexpci ceiling, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("Budget Ceiling") 
    ytitle("Probability of Discrimination") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppdceiling_fmw.eps, replace;
qui drop sim_*;
qui drop b1 b2 b3 b4 b5 b6;

/***************************************************************************
** Common Structural Policies
*/
set seed 160773;
estsimpx bcse_probit discr_csp prob_csp `discrimination_model', area(csp);

setx prob_csp p25 (ceiling share_exp) p25 (perccouncil_change importfromeu) p75;
simqix, prval(1) listx;
setx prob_csp median (ceiling share_exp) p25 (perccouncil_change importfromeu) p75;
simqix, prval(1) listx;
setx prob_csp p75 (ceiling share_exp) p25 (perccouncil_change importfromeu) p75;
simqix, prval(1) listx;

setx median;
setx prob_csp p25;
simqix, prval(1) listx;
setx prob_csp median;
simqix, prval(1) listx;
setx prob_csp p75;
simqix, prval(1) listx;

setx prob_csp p25 (ceiling share_exp) p75 (perccouncil_change importfromeu) p25;
simqix, prval(1) listx;
setx prob_csp median (ceiling share_exp) p75 (perccouncil_change importfromeu) p25;
simqix, prval(1) listx;
setx prob_csp p75 (ceiling share_exp) p75 (perccouncil_change importfromeu) p25;
simqix, prval(1) listx;

setx median;
simexpci perccouncil_change, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("EU Member Council Power") 
    ytitle("Probability of Discrimination") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppdcvoting_csp.eps, replace;
qui drop sim_*;

setx (ceiling share_exp) p25 (perccouncil_change importfromeu) p75;
simexpci prob_csp, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("Probability of Discrimination Demand") 
    ytitle("Probability of Discrimination") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppd_csp.eps, replace;
qui drop sim_*;

setx median;
simexpci ceiling, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("Budget Ceiling") 
    ytitle("Probability of Discrimination") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppdceiling_csp.eps, replace;
qui drop sim_*;
qui drop b1 b2 b3 b4 b5 b6;


/***************************************************************************
** Common Agricultural Policies
*/
set seed 160773;
estsimpx bcse_probit discr_cap prob_cap `discrimination_model', area(cap);

setx prob_cap p25 (ceiling perccouncil_change share_exp) p25 importfromeu p75;
simqix, prval(1) listx;
setx prob_cap median (ceiling perccouncil_change share_exp) p25 importfromeu p75;
simqix, prval(1) listx;
setx prob_cap p75 (ceiling perccouncil_change share_exp) p25 importfromeu p75;
simqix, prval(1) listx;

setx median;
setx prob_cap p25;
simqix, prval(1) listx;
setx prob_cap median;
simqix, prval(1) listx;
setx prob_cap p75;
simqix, prval(1) listx;

setx prob_cap p25 (ceiling perccouncil_change share_exp) p75 importfromeu p25;
simqix, prval(1) listx;
setx prob_cap median (ceiling perccouncil_change share_exp) p75 importfromeu p25;
simqix, prval(1) listx;
setx prob_cap p75 (ceiling perccouncil_change share_exp) p75 importfromeu p25;
simqix, prval(1) listx;

setx median;
simexpci perccouncil_change, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("EU Member Council Power") 
    ytitle("Probability of Discrimination") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppdcvoting_cap.eps, replace;
qui drop sim_*;

setx (ceiling perccouncil_change share_exp) p25 importfromeu p75;
simexpci prob_cap, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("Probability of Discrimination Demand") 
    ytitle("Probability of Discrimination") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppd_cap.eps, replace;
qui drop sim_*;

setx median;
simexpci ceiling, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("Budget Ceiling") 
    ytitle("Probability of Discrimination") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppdceiling_cap.eps, replace;
qui drop sim_*;
qui drop b1 b2 b3 b4 b5 b6;

set more on;
log close;
