/****************************************************************************
** 
** File name   : sims_chap5.do
** Date        : July 18, 2008
** Author      : Christina J. Schneider 
** Purpose     : Creates Predicted Probabilities Graphs with Clarify 
**			for each policy area
** Requires    : replication_final.dta 
** Output      : sims_chap5.log
** Info        : README
** NOTE	   : The simulation results cannot be exactly replicated because
**			they depend on random draws from the normal distribution
**			and the only way to ensure exact matches is to seed the 
**			random number generator with the same number (which I did
**			not do).			
**
*****************************************************************************/

version 10

set more off


#delimit ;

/*
** Call simexpci varname, ticks(obs_to_generate) conf(conf_level)
**      ticks(n) is how many observation b/n auth min and max to generate
**      conf(n)  is the confidence level for the intervals (default 95%)
** RETURNS
**      sim_x with `ticks' observations from min to max of `varname'
**      sim_exp  expected value of dependent var
**      sim_ciL and sim_ciH: the lower and upper bounds of conf. interval
*/
program define simexpci;
    syntax varname, TICKS(integer) [CONF(integer $S_level)];

    tempvar dummyvar expvar;

    * calc bounds for conf. intervals;
    loc left = (100-`conf')/2;
    loc right = 100-`left';

    * at least two ticks for end values;
    loc ticks = cond(`ticks'>1,`ticks',2);

    * calc values for `varname' from ticks;
    qui sum `varlist';
    loc themin = r(min);
    loc themax = r(max);
    loc thestep = (`themax'-`themin')/(`ticks'-1);

    * generate place-holder variables;
    capture confirm new var sim_x;
    if _rc == 0 {;
        loc next = `themin'+`thestep';
        qui egen sim_x = fill(`themin' `next');
        qui replace sim_x = . if sim_x > `themax';

        qui gen sim_exp = .;
        label var sim_exp "Expected value";
        qui gen sim_ciL = .;
        label var sim_ciL "Lower bound (ci)";
        qui gen sim_ciH = .;
        label var sim_ciH "Upper bound (ci)";
    };

    * predict and stuff into variables;
    loc i = 1;
    loc prevpct = 0;
    di _n "% complete: " _c;
    while `i' <= `ticks' {;
        loc percent = int(`i'*100/`ticks');
        if `percent'>=`prevpct'+20 {;
            loc prevpct = `percent';
            di "`percent'.." _c;
        };

        loc x = min(`themin' + `thestep'*(`i'-1), `themax');
        qui replace sim_x = `x' if _n==`i';
        setx `varlist' `x';

        qui simqi, genpr(`dummyvar' `expvar');
        /* we want pr(y=1) only, so take 2nd argument */
        su `expvar', meanonly;
        qui replace sim_exp = r(mean) if _n==`i';
        _pctile `expvar', p(`left' `right');
        qui replace sim_ciL = r(r1) if _n==`i';
        qui replace sim_ciH = r(r2) if _n==`i';

        drop `dummyvar' `expvar';
        loc i = `i' + 1;
    };
    di "Done";
end;

/*
****************************************************************************
** MAIN PROGRAM
****************************************************************************
*/

drop _all;
set more off;
set logtype text;
set linesize 90;

log query;
loc logstatus = r(status);
if "`logstatus'" == "on" {; 
	log close; 
};
log using sims_chap5, replace;

di "Graphs for the Models in Chapter 5";
di "$S_DATE $S_TIME";

/*
****************************************************************************
*/
di "Graphs for the Free Movement of Workers Model";

use replication_final, clear;

drop if freedomofmovement != 1;

estsimp probit demdisdum bipn_eu100 distance foreign erwerbindo erwerbindn unempln unemplo 
                         expbip polityivnew contribution pop65perc
              , cluster(oldmembers) genname(bsim);

setx median;
simexpci foreign, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("EU Member Share of Foreigners") 
    ytitle("Probability of Discrimination Demand") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppanforeign.eps, replace;
qui drop sim_*;

setx median;
simexpci bipn_eu100, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("Candidate GDP (Percent of EU Average)") 
    ytitle("Probability of Discrimination Demand") 
    ylabel(0(.1).5)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppangdp.eps, replace;
qui drop sim_*;

setx median;
simexpci erwerbindo, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("EU Member Industry Employment") 
    ytitle("Probability of Discrimination Demand") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppanindsecm.eps, replace;
qui drop sim_*;

setx median;
simexpci erwerbindn, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("Candidate Industry Employment") 
    ytitle("Probability of Discrimination Demand") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppanindsecc.eps, replace;
qui drop sim_*;

setx median;
simexpci unempln, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("Candidate Unemployment") 
    ytitle("Probability of Discrimination Demand") 
    ylabel(0(.1).5)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppanunem.eps, replace;
qui drop sim_*;

/*
****************************************************************************
*/
di "Graphs for the Common Agricultural Policies Model";

use replication_final, clear;

drop if agriculture != 1;

estsimp probit demdisdum totagrn totagro sizen contribution erwerblandn bipn_eu100 expbip polityivnew
              , cluster(oldmembers) genname(bsim);

setx median;
simexpci totagro, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("EU Member Agriculture GVA") 
    ytitle("Probability of Discrimination Demand") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppcapgavm.eps, replace;
qui drop sim_*;

setx median;
simexpci totagrn, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("Candidate Agriculture GVA") 
    ytitle("Probability of Discrimination Demand") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppcapgavc.eps, replace;
qui drop sim_*;

setx median;
simexpci sizen, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("Expected Size of the EU") 
    ytitle("Probability of Discrimination Demand") 
    ylabel(0(.2).8)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppcapsize.eps, replace;
qui drop sim_*;

setx median;
simexpci contribution, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("EU Member Budget Contributions") 
    ytitle("Probability of Discrimination Demand") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppcapcont.eps, replace;
qui drop sim_*;


/*
****************************************************************************
*/
di "Graphs for the Common Structural Policies Model";

use replication_final, clear;

drop if structuralfunds != 1;

estsimp probit demdisdum bipn_eu100 fundo sizen erwerbindn erwerblandn contribution 
               expbip polityivnew
              , cluster(oldmembers) genname(bsim);

setx median;
simexpci fundo, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("EU Member ERDF/ESF Amount") 
    ytitle("Probability of Discrimination Demand") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppsffunds.eps, replace;
qui drop sim_*;

setx median;
simexpci bipn_eu100, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("Candidate GDP (Percent of EU Average)") 
    ytitle("Probability of Discrimination Demand") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppsfgdp.eps, replace;
qui drop sim_*;

setx median;
simexpci contribution, ticks(50) conf(95);
graph twoway 
    line sim_exp sim_x, lcolor(black) 
 || line sim_ciL sim_x, lcolor(black) lpattern(dash)  
 || line sim_ciH sim_x, lcolor(black) lpattern(dash) 
    xtitle("EU Member Budget Contributions") 
    ytitle("Probability of Discrimination Demand") 
    ylabel(0(.2)1)
    note("Solid line shows predicted probabilities; dashed lines show 95% confidence interval") 
    legend(off)  
    graphregion(fcolor(white));
graph export ppsfcontrib.eps, replace;
qui drop sim_*;

log close;
